summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChris Ward <chris@chrisgward.com>2013-04-06 23:43:09 +1100
committerChris Ward <chris@chrisgward.com>2013-04-06 23:43:09 +1100
commit4cf954d90b8852f494f7b070d036e39a0ae5dce4 (patch)
treec01b223c10b6445d82f810a1f0886b545bdbb86a
parent5826366dd23e09a1877cd8b048362947500522f0 (diff)
downloadEssentials-4cf954d90b8852f494f7b070d036e39a0ae5dce4.tar
Essentials-4cf954d90b8852f494f7b070d036e39a0ae5dce4.tar.gz
Essentials-4cf954d90b8852f494f7b070d036e39a0ae5dce4.tar.lz
Essentials-4cf954d90b8852f494f7b070d036e39a0ae5dce4.tar.xz
Essentials-4cf954d90b8852f494f7b070d036e39a0ae5dce4.zip
Fix spelling mistakes
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/Kits.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/api/Economy.java4
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/api/IUser.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/commands/Commandfirework.java6
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/commands/EssentialsCommandHandler.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/craftbukkit/SetExpFix.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/economy/Economy.java4
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/listener/EssentialsPluginListener.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/settings/SpawnsHolder.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/settings/commands/Help.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/user/User.java8
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/user/UserBase.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/net/ess3/utils/DescParseTickFormat.java2
-rwxr-xr-x[-rw-r--r--]Essentials/src/oldTranslations/README4
-rwxr-xr-x[-rw-r--r--]Essentials2Compat/src/com/earth2me/essentials/Economy.java4
-rwxr-xr-x[-rw-r--r--]EssentialsProtect/src/net/ess3/protect/EssentialsProtect.java2
-rwxr-xr-x[-rw-r--r--]EssentialsSigns/src/net/ess3/signs/SignConfig.java2
-rwxr-xr-x[-rw-r--r--]EssentialsUpdate/src/net/ess3/update/tasks/InstallModule.java2
18 files changed, 27 insertions, 27 deletions
diff --git a/Essentials/src/net/ess3/Kits.java b/Essentials/src/net/ess3/Kits.java
index 28e4c8dac..60dad63e0 100644..100755
--- a/Essentials/src/net/ess3/Kits.java
+++ b/Essentials/src/net/ess3/Kits.java
@@ -90,7 +90,7 @@ public class Kits extends AsyncStorageObjectHolder<net.ess3.settings.Kits> imple
else if (lastTime > time.getTimeInMillis())
{
// This is to make sure time didn't get messed up on last kit use.
- // If this happens, let's give the user the benifit of the doubt.
+ // If this happens, let's give the user the benefit of the doubt.
user.setTimestamp(TimestampType.KIT, time.getTimeInMillis());
}
else
diff --git a/Essentials/src/net/ess3/api/Economy.java b/Essentials/src/net/ess3/api/Economy.java
index 046c6e1f6..d59c28aa9 100644..100755
--- a/Essentials/src/net/ess3/api/Economy.java
+++ b/Essentials/src/net/ess3/api/Economy.java
@@ -64,10 +64,10 @@ public final class Economy
}
/**
- * Substracts money from the balance of a user
+ * Subtracts money from the balance of a user
*
* @param name Name of the user
- * @param amount The money you want to substract
+ * @param amount The money you want to subtract
* @throws UserDoesNotExistException If a user by that name does not exists
* @throws NoLoanPermittedException If the user is not allowed to have a negative balance
*/
diff --git a/Essentials/src/net/ess3/api/IUser.java b/Essentials/src/net/ess3/api/IUser.java
index 2644572b1..007290a0c 100644..100755
--- a/Essentials/src/net/ess3/api/IUser.java
+++ b/Essentials/src/net/ess3/api/IUser.java
@@ -40,7 +40,7 @@ public interface IUser extends OfflinePlayer, CommandSender, IStorageObjectHolde
void setMoney(double value);
- void payUser(final IUser reciever, final double value) throws Exception;
+ void payUser(final IUser receiver, final double value) throws Exception;
void setLastLocation();
diff --git a/Essentials/src/net/ess3/commands/EssentialsCommandHandler.java b/Essentials/src/net/ess3/commands/EssentialsCommandHandler.java
index 1910f3f6a..f2bb367c8 100644..100755
--- a/Essentials/src/net/ess3/commands/EssentialsCommandHandler.java
+++ b/Essentials/src/net/ess3/commands/EssentialsCommandHandler.java
@@ -89,7 +89,7 @@ public class EssentialsCommandHandler implements ICommandHandler, TabExecutor
return true;
}
- final String commandName = command.getName().toLowerCase(Locale.ENGLISH); // TODO: Isn't this just the commandLable
+ final String commandName = command.getName().toLowerCase(Locale.ENGLISH); // TODO: Isn't this just the commandLabel
IEssentialsCommand cmd = commands.get(commandName);
if (cmd == null)
{
diff --git a/Essentials/src/net/ess3/craftbukkit/SetExpFix.java b/Essentials/src/net/ess3/craftbukkit/SetExpFix.java
index bef354167..e52ea849d 100644..100755
--- a/Essentials/src/net/ess3/craftbukkit/SetExpFix.java
+++ b/Essentials/src/net/ess3/craftbukkit/SetExpFix.java
@@ -17,7 +17,7 @@ public class SetExpFix
player.setLevel(0);
player.setTotalExperience(0);
- //This following code is technically redundant now, as bukkit now calulcates levels more or less correctly
+ //This following code is technically redundant now, as bukkit now calculates levels more or less correctly
//At larger numbers however... player.getExp(3000), only seems to give 2999, putting the below calculations off.
int amount = exp;
while (amount > 0)
diff --git a/Essentials/src/net/ess3/economy/Economy.java b/Essentials/src/net/ess3/economy/Economy.java
index a2a25738b..d34044e32 100644..100755
--- a/Essentials/src/net/ess3/economy/Economy.java
+++ b/Essentials/src/net/ess3/economy/Economy.java
@@ -28,10 +28,10 @@ public class Economy implements IEconomy
return balance;
}
- private void setNPCBalance(String name, double balance, boolean checkExistance) throws UserDoesNotExistException
+ private void setNPCBalance(String name, double balance, boolean checkExistence) throws UserDoesNotExistException
{
Map<String, Double> balances = npcs.getData().getBalances();
- if (checkExistance && !balances.containsKey(name.toLowerCase(Locale.ENGLISH)))
+ if (checkExistence && !balances.containsKey(name.toLowerCase(Locale.ENGLISH)))
{
throw new UserDoesNotExistException(name);
}
diff --git a/Essentials/src/net/ess3/listener/EssentialsPluginListener.java b/Essentials/src/net/ess3/listener/EssentialsPluginListener.java
index 1953632b6..9fa17750c 100644..100755
--- a/Essentials/src/net/ess3/listener/EssentialsPluginListener.java
+++ b/Essentials/src/net/ess3/listener/EssentialsPluginListener.java
@@ -48,7 +48,7 @@ public class EssentialsPluginListener implements Listener, IReload
checkGroups();
ess.getPlugin().onPluginDisable(event.getPlugin());
ess.getCommandHandler().removePlugin(event.getPlugin());
- // Check to see if the plugin thats being disabled is the one we are using
+ // Check to see if the plugin that's being disabled is the one we are using
if (Methods.hasMethod() && Methods.checkDisabled(event.getPlugin()))
{
Methods.reset();
diff --git a/Essentials/src/net/ess3/settings/SpawnsHolder.java b/Essentials/src/net/ess3/settings/SpawnsHolder.java
index 9be12ca9f..1550785c3 100644..100755
--- a/Essentials/src/net/ess3/settings/SpawnsHolder.java
+++ b/Essentials/src/net/ess3/settings/SpawnsHolder.java
@@ -37,7 +37,7 @@ public class SpawnsHolder extends AsyncStorageObjectHolder<Spawns>
* Sets a spawn location
*
* @param loc - Location you want to set as spawn
- * @param group - Group to save it undr in the config
+ * @param group - Group to save it under in the config
*/
public void setSpawn(final Location loc, final String group)
{
diff --git a/Essentials/src/net/ess3/settings/commands/Help.java b/Essentials/src/net/ess3/settings/commands/Help.java
index dcc2f6c97..0d5a6f607 100644..100755
--- a/Essentials/src/net/ess3/settings/commands/Help.java
+++ b/Essentials/src/net/ess3/settings/commands/Help.java
@@ -15,7 +15,7 @@ public class Help implements StorageObject
@Comment(
"Hide plugins which don't give a permission in their plugin.yml for each command.\n"
+ "You can override a true value here for a single plugin by adding a permission to a user/group.\n"
- + "The individual permission is: essentials.help.<plugin>, anyone with essentials.* or '*' will see all help this setting reguardless.\n"
+ + "The individual permission is: essentials.help.<plugin>, anyone with essentials.* or '*' will see all help this setting regardless.\n"
+ "You can use negative permissions to remove access to just a single plugins help if the following is enabled.")
private boolean hidePermissionlessCommands = true;
}
diff --git a/Essentials/src/net/ess3/user/User.java b/Essentials/src/net/ess3/user/User.java
index 1cc309a0f..dc2cbeac6 100644..100755
--- a/Essentials/src/net/ess3/user/User.java
+++ b/Essentials/src/net/ess3/user/User.java
@@ -129,7 +129,7 @@ public class User extends UserBase implements IUser
}
@Override
- public void payUser(final IUser reciever, final double value) throws Exception
+ public void payUser(final IUser receiver, final double value) throws Exception
{
if (value == 0)
{
@@ -138,9 +138,9 @@ public class User extends UserBase implements IUser
if (canAfford(value))
{
setMoney(getMoney() - value);
- reciever.setMoney(reciever.getMoney() + value);
- sendMessage(_("{0} has been sent to {1}.", FormatUtil.displayCurrency(value, ess), reciever.getPlayer().getDisplayName()));
- reciever.sendMessage(_("{0} has been received from {1}.", FormatUtil.displayCurrency(value, ess), getPlayer().getDisplayName()));
+ receiver.setMoney(receiver.getMoney() + value);
+ sendMessage(_("{0} has been sent to {1}.", FormatUtil.displayCurrency(value, ess), receiver.getPlayer().getDisplayName()));
+ receiver.sendMessage(_("{0} has been received from {1}.", FormatUtil.displayCurrency(value, ess), getPlayer().getDisplayName()));
}
else
{
diff --git a/Essentials/src/net/ess3/user/UserBase.java b/Essentials/src/net/ess3/user/UserBase.java
index f37019565..74bc39cdc 100644..100755
--- a/Essentials/src/net/ess3/user/UserBase.java
+++ b/Essentials/src/net/ess3/user/UserBase.java
@@ -315,7 +315,7 @@ public abstract class UserBase extends AsyncStorageObjectHolder<UserData> implem
for (Location location : worldHomes)
{
final double d = loc.distanceSquared(location);
- if (d < distance) // TODO: Shouldnt this just use Double.isInfinite(v); rather than create a new Double of maxval?
+ if (d < distance) // TODO: Shouldn't this just use Double.isInfinite(v); rather than create a new Double of maxval?
{
target = location;
distance = d;
diff --git a/Essentials/src/net/ess3/utils/DescParseTickFormat.java b/Essentials/src/net/ess3/utils/DescParseTickFormat.java
index f6d0dd227..e8b37fc42 100644..100755
--- a/Essentials/src/net/ess3/utils/DescParseTickFormat.java
+++ b/Essentials/src/net/ess3/utils/DescParseTickFormat.java
@@ -279,7 +279,7 @@ public final class DescParseTickFormat
// How many seconds on the last day?
final long seconds = (long)Math.floor(dticks / ticksPerSecond);
- // Now we create an english GMT calendar (We wan't no daylight savings)
+ // Now we create an english GMT calendar (We want no daylight savings)
final Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT"), Locale.ENGLISH);
cal.setLenient(true);
diff --git a/Essentials/src/oldTranslations/README b/Essentials/src/oldTranslations/README
index c467d2138..53b1de6e9 100644..100755
--- a/Essentials/src/oldTranslations/README
+++ b/Essentials/src/oldTranslations/README
@@ -1,3 +1,3 @@
These translation files have partially translated messages, based off the old early essentials colour scheme.
-All the commands need a cleanup, and the new colour scheme implementing throught.
-Only once cleanup is done should retranslations begin. \ No newline at end of file
+All the commands need a cleanup, and the new colour scheme implementing throughout.
+Only once cleanup is done should re-translations begin. \ No newline at end of file
diff --git a/Essentials2Compat/src/com/earth2me/essentials/Economy.java b/Essentials2Compat/src/com/earth2me/essentials/Economy.java
index 15f0045ac..aa383a40c 100644..100755
--- a/Essentials2Compat/src/com/earth2me/essentials/Economy.java
+++ b/Essentials2Compat/src/com/earth2me/essentials/Economy.java
@@ -68,10 +68,10 @@ public final class Economy
}
/**
- * Substracts money from the balance of a user
+ * Subtracts money from the balance of a user
*
* @param name Name of the user
- * @param amount The money you want to substract
+ * @param amount The money you want to subtract
* @throws UserDoesNotExistException If a user by that name does not exists
* @throws NoLoanPermittedException If the user is not allowed to have a negative balance
*/
diff --git a/EssentialsProtect/src/net/ess3/protect/EssentialsProtect.java b/EssentialsProtect/src/net/ess3/protect/EssentialsProtect.java
index dec2ecd8f..2bb765b50 100644..100755
--- a/EssentialsProtect/src/net/ess3/protect/EssentialsProtect.java
+++ b/EssentialsProtect/src/net/ess3/protect/EssentialsProtect.java
@@ -45,7 +45,7 @@ public class EssentialsProtect extends JavaPlugin implements IProtect
{
player.sendMessage("Essentials Protect is in emergency mode. Check your log for errors."); //TODO: tl this
}
- LOGGER.log(Level.SEVERE, "Essentials not installed or failed to load. Essenials Protect is in emergency mode now."); //TODO: tl this
+ LOGGER.log(Level.SEVERE, "Essentials not installed or failed to load. Essentials Protect is in emergency mode now."); //TODO: tl this
}
@Override
diff --git a/EssentialsSigns/src/net/ess3/signs/SignConfig.java b/EssentialsSigns/src/net/ess3/signs/SignConfig.java
index 7c185eb05..bffe06948 100644..100755
--- a/EssentialsSigns/src/net/ess3/signs/SignConfig.java
+++ b/EssentialsSigns/src/net/ess3/signs/SignConfig.java
@@ -26,7 +26,7 @@ public class SignConfig implements StorageObject
@Comment(
"How many times per second can Essentials signs be interacted with.\n"
+ "Values should be between 1-20, 20 being virtually no lag protection.\n"
- + "Lower numbers will reduce the possiblity of lag, but may annoy players.")
+ + "Lower numbers will reduce the possibility of lag, but may annoy players.")
private int signUsesPerSecond = 4;
public int getSignUsePerSecond()
diff --git a/EssentialsUpdate/src/net/ess3/update/tasks/InstallModule.java b/EssentialsUpdate/src/net/ess3/update/tasks/InstallModule.java
index 239553acd..1a202c02b 100644..100755
--- a/EssentialsUpdate/src/net/ess3/update/tasks/InstallModule.java
+++ b/EssentialsUpdate/src/net/ess3/update/tasks/InstallModule.java
@@ -54,7 +54,7 @@ public class InstallModule implements Runnable, Task
catch (Exception ex)
{
Bukkit.getLogger().log(Level.SEVERE, "Failed to download module " + moduleName + " to " + fileName, ex);
- listener.onWorkAbort("An error occured, please check your server log.");
+ listener.onWorkAbort("An error occurred, please check your server log.");
}
}
}
diff --git a/Essentials/src/net/ess3/commands/Commandfirework.java b/Essentials/src/net/ess3/commands/Commandfirework.java
index 46944a6cc..aa1e60880 100644..100755
--- a/Essentials/src/net/ess3/commands/Commandfirework.java
+++ b/Essentials/src/net/ess3/commands/Commandfirework.java
@@ -18,7 +18,7 @@ import org.bukkit.inventory.meta.FireworkMeta;
import org.bukkit.util.Vector;
//This command has quite a complicated syntax, in theory it has 4 seperate syntaxes which are all variable:
//
//1: /firework clear - This clears all of the effects on a firework stack
//
@@ -118,7 +118,7 @@ public class Commandfirework extends EssentialsCommand
}
catch (Exception e)
{
- user.sendMessage(_("Firework parameters: color:<color> [fade:<color>] [shape:<shape>] [effect:<effect>]nTo use multiple colors/effects, seperate values with commas: red,blue,pinknShapes: star, ball, large, creeper, burst Effects: trail, twinkle."));
+ user.sendMessage(_("Firework parameters: color:<color> [fade:<color>] [shape:<shape>] [effect:<effect>]nTo use multiple colors/effects, separate values with commas: red,blue,pinknShapes: star, ball, large, creeper, burst Effects: trail, twinkle."));
throw e;
}
}
@@ -136,7 +136,7 @@ public class Commandfirework extends EssentialsCommand
}
else
{
- user.sendMessage(_("Firework parameters: color:<color> [fade:<color>] [shape:<shape>] [effect:<effect>]nTo use multiple colors/effects, seperate values with commas: red,blue,pinknShapes: star, ball, large, creeper, burst Effects: trail, twinkle."));
+ user.sendMessage(_("Firework parameters: color:<color> [fade:<color>] [shape:<shape>] [effect:<effect>]nTo use multiple colors/effects, separate values with commas: red,blue,pinknShapes: star, ball, large, creeper, burst Effects: trail, twinkle."));
throw new Exception(_("Invalid firework charge parameters inserted, must set a color first."));
}
}
@@ -18,7 +18,7 @@ import org.bukkit.inventory.meta.FireworkMeta;
import org.bukkit.util.Vector;
-//This command has quite a complicated syntax, in theory it has 4 seperate syntaxes which are all variable:
+//This command has quite a complicated syntax, in theory it has 4 separate syntaxes which are all variable:
//
//1: /firework clear - This clears all of the effects on a firework stack